@@ -11,7 +11,7 @@ use Syntax::Kamelon::Indexer;
 use Module::Load::Conditional qw[can_load];
 use Data::Dumper;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 my @attributes = qw (
 	Alert
@@ -315,24 +315,12 @@ sub InitFormatter {
 	}
 }
 
-sub IsDeliminator {
-	my ($self, $char) = @_;
-	my $deliminators = '\s|\~|\!|\%|\^|\&|\*|\+|\(|\)|-|=|\{|\}|\[|\]|:|;|<|>|,|\\|\||\.|\?|\/';
-# 	my $deliminators = $self->deliminators;
-	if ($char =~ /$deliminators/) { return 1 }
-	return ''
-}
-
-sub LastcharBoundary {
-	my $self = shift;
-	my $l = $self->LastChar;
-	return ($l =~ /\b/)
-}
-
 sub LastcharDeliminator {
-	my $self = shift;
-	if ($self->LineStart) { return 1 }
-	return ($self->IsDeliminator($self->LastChar))
+	my ($self, $delim) = @_;
+	return 1 if $self->LineStart;
+	my $last = $self->LastChar;
+# 	return 1 if $last eq '';
+	return $last =~ /$delim/
 }
 
 sub LastChar {
@@ -665,14 +653,32 @@ sub StateSet {
 
 sub SuggestSyntax {
 	my ($self, $file) = @_;
-	my $hsh = $self->{INDEXER}->Extensions;
+	my $id = $self->GetIndexer;
+	my $hsh = $id->Extensions;
 	my $ext;
 	if ($file =~ /(\.[^\.]+)$/) {
 		$ext = $1;
 	}
 	return undef unless defined $ext;
-	my $key = "*$ext";
-	return $hsh->{$key}->[0] if exists $hsh->{$key};
+	my $list = $hsh->{"*$ext"};
+	if (defined $list) {
+		my @l = @$list;
+		my $syntax = shift @l;
+		while (@l) {
+			my $new = shift @l;
+
+			my $pnew = $id->InfoPriority($new);
+			$pnew = 0 unless defined $pnew;
+			$pnew = 0 unless $pnew =~ /^\d+$/;
+
+			my $psyntax = $id->InfoPriority($syntax);
+			$psyntax = 0 unless defined $psyntax;
+			$psyntax = 0 unless $psyntax =~ /^\d+$/;
+
+			$syntax = $new if $pnew > $psyntax;
+		}
+		return $syntax
+	}
 	return undef;
 }
 
@@ -885,8 +891,9 @@ sub testDetect2CharsI {
 sub testDetectIdentifier {
 	my $self = shift;
 	my $text = shift;
-	unless ($self->LastcharDeliminator) { return '' }
-	if ($$text =~ /^([a-z][a-z0-9_]*)/i) {
+	my $delim = shift;
+	return '' unless $self->LastcharDeliminator($delim);
+	if ($$text =~ /^([a-zA-Z_][a-zA-Z0-9_]*)/) {
 		my $parser = pop @_;
 		&$parser($self, $text, $1, @_);
 		return 1
@@ -908,12 +915,12 @@ sub testDetectSpaces {
 sub testFloat {
 	my $self = shift;
 	my $text = shift;
-	if ($self->LastcharDeliminator) {
-		if ($$text =~ /^((?=\.?\d)\d*(?:\.\d*)?(?:[Ee][+-]?\d+)?)/) {
-			my $parser = pop @_;
-			&$parser($self, $text, $1, @_);
-			return 1
-		}
+	my $delim = shift;
+	return '' unless $self->LastcharDeliminator($delim);
+	if ($$text =~ /^((?=\.?\d)\d*(?:\.\d*)?(?:[Ee][+-]?\d+)?)/) {
+		my $parser = pop @_;
+		&$parser($self, $text, $1, @_);
+		return 1
 	}
 	return ''
 }
@@ -932,12 +939,12 @@ sub testHlCChar {
 sub testHlCHex {
 	my $self = shift;
 	my $text = shift;
-	if ($self->LastcharDeliminator) {
-		if ($$text =~ /^(0x[0-9a-fA-F]+)/) {
-			my $parser = pop @_;
-			&$parser($self, $text, $1, @_);
-			return 1
-		}
+	my $delim = shift;
+	return '' unless $self->LastcharDeliminator($delim);
+	if ($$text =~ /^(0x[0-9a-fA-F]+)/) {
+		my $parser = pop @_;
+		&$parser($self, $text, $1, @_);
+		return 1
 	}
 	return ''
 }
@@ -945,12 +952,12 @@ sub testHlCHex {
 sub testHlCOct {
 	my $self = shift;
 	my $text = shift;
-	if ($self->LastcharDeliminator) {
-		if ($$text =~ /^(0[0-7]+)/) {
-			my $parser = pop @_;
-			&$parser($self, $text, $1, @_);
-			return 1;
-		}
+	my $delim = shift;
+	return '' unless $self->LastcharDeliminator($delim);
+	if ($$text =~ /^(0[0-7]+)/) {
+		my $parser = pop @_;
+		&$parser($self, $text, $1, @_);
+		return 1;
 	}
 	return ''
 }
@@ -979,26 +986,23 @@ sub testHlCStringChar {
 sub testInt {
 	my $self = shift;
 	my $text = shift;
-	if ($self->LastcharDeliminator) {
-		if ($$text =~ /^([+-]?\d+)/) {
-			my $parser = pop @_;
-			&$parser($self, $text, $1, @_);
-			return 1
-		}
+	my $delim = shift;
+	return '' unless $self->LastcharDeliminator($delim);
+	if ($$text =~ /^([+-]?\d+)/) {
+		my $parser = pop @_;
+		&$parser($self, $text, $1, @_);
+		return 1
 	}
 	return ''
 }
 
 sub testKeyword {
 	my $self = shift;
-	unless ($self->LastcharDeliminator) { return '' }
 	my $text = shift;
 	my $list = shift;
 	my $delim = shift;
-# 	my $deliminators = $self->StackTop->[0]->{deliminators};
-# 	if ($$text =~ /^([^$deliminators]+)/) {
+	return '' unless $self->LastcharDeliminator($delim);
 	if ($$text =~ /^([^$delim]+)/) {
-# 	if ($$text =~ /^([^\b]+)/) {
 		my $match = $1;
 		if (exists $list->{$match}) {
 			my $parser = pop @_;
@@ -1011,14 +1015,11 @@ sub testKeyword {
 
 sub testKeywordI {
 	my $self = shift;
-	unless ($self->LastcharDeliminator) { return '' }
 	my $text = shift;
 	my $list = shift;
 	my $delim = shift;
-# 	my $deliminators = $self->StackTop->[0]->{deliminators};
-# 	if ($$text =~ /^([^$deliminators]+)/) {
+	return '' unless $self->LastcharDeliminator($delim);
 	if ($$text =~ /^([^$delim]+)/) {
-# 	if ($$text =~ /^([^\b]+)/) {
 		my $match = $1;
 		my $test = lc($match);
 		if (exists $list->{$test}) {
@@ -1230,10 +1231,11 @@ sub testWordDetect {
 	my $self = shift;
 	my $text = shift;
 	my $string = shift;
-	if (length($string) + 1 > length($$text)) { return '' }
-	unless ($self->LastcharDeliminator) { return '' }
+	my $delim = shift;
+	return '' if (length($string) + 1 > length($$text));
+	return '' unless $self->LastcharDeliminator($delim);
 	my $testc = substr($$text, length($string), 1);
-	unless ($self->IsDeliminator($testc)) { return '' }
+	return '' unless $testc =~ /$delim/;
 	my $test = substr($$text, 0, length($string));
 	if ($string eq $test) {
 		my $parser = pop @_;
@@ -1247,11 +1249,12 @@ sub testWordDetectD {
 	my $self = shift;
 	my $text = shift;
 	my $string = shift;
-	if (length($string) + 1 > length($$text)) { return '' }
+	my $delim = shift;
 	$string = $self->CapturedParse($string);
-	unless ($self->LastcharDeliminator) { return '' }
+	return '' if (length($string) + 1 > length($$text));
+	return '' unless $self->LastcharDeliminator($delim);
 	my $testc = substr($$text, length($string), 1);
-	unless ($self->IsDeliminator($testc)) { return '' }
+	return '' unless $testc =~ /$delim/;
 	my $test = substr($$text, 0, length($string));
 	if ($string eq $test) {
 		my $parser = pop @_;
@@ -1265,11 +1268,12 @@ sub testWordDetectDI {
 	my $self = shift;
 	my $text = shift;
 	my $string = shift;
-	if (length($string) + 1 > length($$text)) { return '' }
+	my $delim = shift;
 	$string = lc($self->CapturedParse($string));
-	unless ($self->LastcharDeliminator) { return '' }
+	return '' if (length($string) + 1 > length($$text));
+	return '' unless $self->LastcharDeliminator($delim);
 	my $testc = substr($$text, length($string), 1);
-	unless ($self->IsDeliminator($testc)) { return '' }
+	return '' unless $testc =~ /$delim/;
 	my $test = substr($$text, 0, length($string));
 	if (lc($string) eq lc($test)) {
 		my $parser = pop @_;
@@ -1283,10 +1287,12 @@ sub testWordDetectI {
 	my $self = shift;
 	my $text = shift;
 	my $string = shift;
-	if (length($string) + 1 > length($$text)) { return '' }
-	unless ($self->LastcharDeliminator) { return '' }
+	my $delim = shift;
+	$string = lc($self->CapturedParse($string));
+	return '' if (length($string) + 1 > length($$text));
+	return '' unless $self->LastcharDeliminator($delim);
 	my $testc = substr($$text, length($string), 1);
-	unless ($self->IsDeliminator($testc)) { return '' }
+	return '' unless $testc =~ /$delim/;
 	my $test = substr($$text, 0, length($string));
 	if (lc($string) eq lc($test)) {
 		my $parser = pop @_;
